from setuptools import setup, find_packages

setup(
    name='erioonDB',
    version='0.1.1',
    description='ErioonDB',
    author='Zyber Pireci',
    author_email='pirecizyber@gmail.com',
    url='https://github.com/Atlantis-Z/medusaproject.git', 
    packages=find_packages(),  
    install_requires=[],  
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License', 
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',  
)
